@@ -123,5 +123,5 @@ if python_prefix_matches and python_version_matches:
         agent.start()
         log_message("agent init end", level=4)
     except BaseException as e:
-        log_message("发生错误了，错误信息是: %s", e)
-        print("发生错误了，错误信息是", e)
+        log_message("FAST: 发生错误了，错误信息是: %s", e)
+        print("FAST: 发生错误了，错误信息是", e)
