@@ -8,6 +8,10 @@ import inspect
 import os
 import re
 import uuid
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from typing import List
 
 import fast_tracker
 from fast_tracker.loggings import logger
@@ -59,6 +63,7 @@ user_code_reader = {"ReaderType": "Cookie", "ReaderKey": "user_code"}
 env_code_reader = {"ReaderType": "Cookie", "ReaderKey": "env_code"}
 # 前端Header
 carrier_header = {"TrackerName": "fast-tracker", "TraceIdName": "x-fast-trace-id"}
+disable_plugins = []  # type: List[str]
 ############################# fast_tracker默认配置信息结束 ###############################
 
 
@@ -203,6 +208,7 @@ def set_socket_timeout(cus_socket_timeout: int = 1):
 def set_event(cus_event: dict):
     """
     设置 event 值
+    目前只有components的数据
     :param cus_event:
     :return:
     """
@@ -210,6 +216,32 @@ def set_event(cus_event: dict):
     if not cus_event:
         return False
     event = cus_event
+    if event.get("Components"):
+        cus_disable_plugins = []
+        component = event.get("Components")
+        if component.get("SqlClient") in ("false", "False", "0", False, 0, -1):
+            cus_disable_plugins.extend(["fast_pymysql", "fast_pymongo", "fast_elasticsearch"])
+        if component.get("HttpClient") in ("false", "False", "0", False, 0, -1):
+            cus_disable_plugins.extend(
+                [
+                    "fast_django",
+                    "fast_falcon",
+                    "fast_flask",
+                    "fast_http_server",
+                    "fast_requests",
+                    "fast_tornado",
+                    "fast_urllib3",
+                    "fast_urllib_request",
+                ]
+            )
+        if component.get("CustomEvent") in ("false", "False", "0", False, 0, -1):
+            cus_disable_plugins.append("custom_event")
+        if component.get("Logging") in ("false", "False", "0", False, 0, -1):
+            cus_disable_plugins.append("fast_log")
+
+        if cus_disable_plugins:
+            global disable_plugins
+            disable_plugins = cus_disable_plugins
 
 
 def set_tenant_code_reader(**kwargs):
@@ -335,7 +367,7 @@ def set_logging(**kwargs):
     global logging_level
     if not kwargs.get("Level"):
         return False
-    logging_level = kwargs.get("Level")
+    logging_level = kwargs.get("Level").upper()
 
 
 def finalize():
