@@ -269,7 +269,7 @@ class FastTracker:
             raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
-        self.span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(message))]))
+        self.span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(message, err_type=""))]))
 
     def error_occurred(self, error: Exception):
         if "custom_event" in config.disable_plugins:
@@ -278,8 +278,8 @@ class FastTracker:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.log(error)
 
-    def log_covert(self, msg: str = ""):
-        return {"err_msg": msg, "err_type": "", "err_trace": ""}
+    def log_covert(self, msg: str = "", err_type: str = "DEBUG"):
+        return {"err_msg": msg, "err_type": err_type if err_type else "", "err_trace": ""}
 
     def end_span(self):
         """
@@ -291,3 +291,35 @@ class FastTracker:
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.stop()
+
+    def debug(self, msg: str = ""):
+        self.__logging(msg, err_type="DEBUG")
+
+    def info(self, msg: str = ""):
+        self.__logging(msg, err_type="INFO")
+
+    def warning(self, msg: str = ""):
+        self.__logging(msg, err_type="WARNING")
+
+    def warn(self, msg: str = ""):
+        self.warning(msg)
+
+    def error(self, msg: str = ""):
+        self.__logging(msg, err_type="ERROR")
+
+    def critical(self, msg: str = ""):
+        self.__logging(msg, err_type="CRITICAL")
+
+    def __logging(self, msg: str = "", err_type: str = ""):
+        try:
+            if "fast_log" in config.disable_plugins:
+                raise RuntimeError("已在配置Event-Components-Logging中关闭此项")
+            context = get_context()
+            if not context:
+                raise RuntimeError("探针未启动")
+            with context.new_local_span(op="Logging") as span:
+                span.layer = Layer.Local
+                span.component = ComponentType.Log
+                span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(msg, err_type="DEBUG"))]))
+        except Exception as e:
+            raise e
